#######################
Registry (``registry``)
#######################

.. automodule:: orangecanvas.registry
   :member-order: bysource

WidgetRegistry
--------------

.. autoclass:: WidgetRegistry
   :members:
   :member-order: bysource

WidgetDescription
-----------------

.. autoclass:: WidgetDescription
   :members:
   :member-order: bysource

CategoryDescription
-------------------

.. autoclass:: CategoryDescription
   :members:
   :member-order: bysource


InputSignal
-----------

.. autoclass:: InputSignal
   :members:
   :member-order: bysource

OutputSignal
------------

.. autoclass:: OutputSignal
   :members:
   :member-order: bysource

WidgetDiscovery
---------------

.. autoclass:: WidgetDiscovery
   :members:
   :member-order: bysource
